<?php

namespace Teknisa\SM\Service;

use Doctrine\ORM\EntityManager;
use Teknisa\SM\Util\Procedure\FctVencPrevCont;
use Teknisa\SM\Util\UtilContrato;
use Teknisa\Libs\Util\NewCode;
use Teknisa\SM\Service\Sm00012000MedicaoFaturamentoService;
use Teknisa\SM\Factory\Sm00004003ReajusteContratoFactory;
use Teknisa\SM\Service\Sm00004000ContratoService;
use Teknisa\SM\Factory\Sm00004000ContratoFactory;
use Teknisa\SM\Service\IntegracaoOmService;

class Sm00004003ReajusteContratoService
{
    protected $connection;
    protected $reajusteContratoFactory;
    protected $contratoService;
    protected $contratoFactory;
    protected $integracaoOmService;
    
    public function __construct(EntityManager $entityManager, NewCode $newCode, Sm00004003ReajusteContratoFactory $reajusteContratoFactory, Sm00004000ContratoService $contratoService, Sm00004000ContratoFactory $contratoFactory, IntegracaoOmService $integracaoOmService, Sm00012000MedicaoFaturamentoService $medicaoService)
    {
        $this->connection              = $entityManager->getConnection();
        $this->newCode                 = $newCode;
        $this->reajusteContratoFactory = $reajusteContratoFactory;
        $this->contratoService         = $contratoService;
        $this->contratoFactory         = $contratoFactory;
        $this->integracaoOmService     = $integracaoOmService;
        $this->medicaoService          = $medicaoService;
    }
    
    //#region  REAJUSTE AUTOMATICO
    /**
     * Função responsável por reajustar todos os contratos de uma organização
     *
     * @param [string] $nrorg - Organização em questão
     */
    public function reajustarContratosAutomaticamente($nrorg)
    {
        //TODO chamar o realizar contrato em massa passando a renovacao como falso
        $resposta = array();
        try {
            $nrSeqContratos = $this->getContratosASeremReajustadosAutomaticamente($nrorg);
            if (count($nrSeqContratos) > 0) {
                $row = array();
                foreach ($nrSeqContratos as $nr) {
                    $contrato = $this->getContratosReajustadosAutomaticamente($nrorg, $nr["NRSEQCONTRATO"]);
                    if (count($contrato) > 0) {
                        $row[] = $contrato[0];
                    }
                }
                if (count($row) > 0) {
                    $this->reajusteContrMassa($row, 1, false, null, true);
                    $teste = array("RESULTADO" => true);
                    $resposta = $teste;
                } else {
                    echo "ORGANIZAÇÃO: " . $nrorg . " | Nenhum contrato a ser reajustado.";
                }
            } else {
                echo "ORGANIZAÇÃO: " . $nrorg . " | Não existe nenhum contrato a ser reajustado.";
            }
        } catch (\Exception $e) {
            echo "ORGANIZAÇÃO: " . $nrorg . " | ERRO ao pegar contratos para serem reajustados automaticamente: " . $e->getMessage();
        }
        return $resposta;
    }

    /**
     * Procedimento responsável por pegar todos os número dos contratos a serem reajustados.
     *
     * @param [String] $nrorg - Organização em questão
     * @return array() todos os contratos a serem reajustados
     */
    public function getContratosASeremReajustadosAutomaticamente($nrorg)
    {
        $row = array();
        try {
            $dataAtual = date_create()->format("d/m/Y");
            $params = array(
                "NRORG" => $nrorg,
                "IDREAJUSTEAUTOMATICO" => "S",
                "DTPADREAJCONT" => $dataAtual
            );
            $row = $this->reajusteContratoFactory->getContratosASeremReajustadosAutomaticamente($params);
        } catch (\Exception $e) {
            echo "ORGANIZAÇÃO: " . $nrorg . " | ERRO ao pegar contratos para serem reajustados automaticamente: " . $e->getMessage();
        }
        return $row;
    }
    
    /**
     * Procedimento responsável por pegar todos os contratos de uma organização que precisam de ser reajustados automaticamente.
     *
     * @param [String] $nrorg - Organização em questão
     * @param [String] $nrseqcontrato - Número do contrato a ser pego
     * @return array() todos os contratos a serem reajustados
     */
    public function getContratosReajustadosAutomaticamente($nrorg, $nrseqcontrato)
    {
        $resposta = array();
        try {
            $nrseqcontrato = "_" . $nrseqcontrato . "_";
            $params = array(
                "NRSEQCONTRATO" => $nrseqcontrato,
                "NRORG" => $nrorg
            );
            $resposta = $this->reajusteContratoFactory->getContratosReajustadosAutomaticamente($params);
            if (!UtilContrato::validaPercentualIndiceFinanceiro($resposta)) {
                throw new \Exception("A soma dos percentuais de utilização dos índices financeiros não está totalizando os 100% necessários para realização do reajuste deste contrato.");
            }
        } catch (\Exception $e) {
            echo "ORGANIZAÇÃO: " . $nrorg . " | ERRO ao pegar os dados do contrato: " . $nrseqcontrato . " | Erro reportado: " . $e->getMessage();
        }
        return $resposta;
    }
    
    /**
     * Procedimento responsável por apagar todos os registros da tabela de Log de uma organização.
     *
     * @param [string] $nrorg - Organização em questão
     * @return void
     */
    public function deletarLogErroReajuste($nrorg)
    {
        try {
            $params = array("NRORG" => $nrorg);
            $this->reajusteContratoFactory->deletarLogErroReajusteContrato($params);
        } catch (\Exception $e) {
            echo "ORGANIZAÇÃO: " . $nrorg . " | ERRO ao deletar logs de contratos de reajuste automaticamente: " . $e->getMessage();
        }
    }
    //#endregion
    
    /**
     * A função "reajustaContrato" centraliza as funções para o reajuste do contrato.
     */
    public function reajustaContrato($row, $nrorg, $cdoperador)
    {
        $this->connection->beginTransaction();
        try {
            /* -- Dados do Contrato -- */
            $nrSeqcontrato = $row['NRSEQCONTRATO'];
            //$nrItemContrato = $row['NRITEMOCONTRATO'];
            $idreajuste = $row['IDREAJUSTE'];
            
            /* -- Percentual -- */
            $percentual = $row['PERCENTUAL'];
            
            /* -- Indice Financeiro -- */
            $cdTpIndice = $row['CDTPINDICE'];
            $idPerValor = $row['IDPERVALOR'];
            $cdIndice  = $row['CDINDICE'];
            $percIndice = $row['PERCINDICE'];

            /* -- Justificativa -- */
            $dsjustificativa = $row['DSJUSTIFICATIVA'];
            
            /* -- Valor Fixo -- */
            $valorFixo = $row['VALORFIXO'];
            $vrPercVarIt = $row['VRPERCVARIACAOIT'];
            
            // $nrParcelanegoCont = $row['NRPARCELANEGOCONT'];
            $nrultimoReajuste = $this->newCode->getCodeByTableName("FCT_NRULTIMOREAJUSTE", $nrorg, 1, 10, true);

            $codNegociacoes = array();
            
            $itensParaAtualizar = $this->getItensFilhosContrato($nrSeqcontrato, $nrorg);
            //Se o contrato é de composição de serviços, entra no if. Senão, entra no else.
            if (count($itensParaAtualizar) > 0) {
                $this->atualizarValorItensContratoComReajuste($nrSeqcontrato, $itensParaAtualizar, $idreajuste, $percentual,$dsjustificativa, $percIndice, $valorFixo, $cdTpIndice, $idPerValor, $cdIndice, $vrPercVarIt, $nrorg, $cdoperador, $nrultimoReajuste);
                $this->atualizarValorItensPaiContrato($nrSeqcontrato, $nrorg, $cdoperador, $nrultimoReajuste);
            } else {
                $itensParaAtualizar = $this->getItensPaiNegociacaoContrato($nrSeqcontrato, $nrorg);
                $this->atualizarValorItensContratoComReajuste($nrSeqcontrato, $itensParaAtualizar, $idreajuste, $percentual, $dsjustificativa, $percIndice, $valorFixo, $cdTpIndice, $idPerValor, $cdIndice, $vrPercVarIt, $nrorg, $cdoperador, $nrultimoReajuste);
            }

            foreach ($itensParaAtualizar as $item) {
                if (!in_array($item["NRNEGOCIACAOCONTRATO"], $codNegociacoes)) {
                    $codNegociacoes[] = $item["NRNEGOCIACAOCONTRATO"];
                }
            }

            foreach ($codNegociacoes as $codNego) {
                //Inserir na tabela FCT_NEGOCIACAOCONTRATO_HR
                $params = $this->getParametroNegociacaoContratoHistoricoRejuste($codNego, $nrorg, $cdoperador, $nrultimoReajuste);
                $this->reajusteContratoFactory->inserirNegociacaoDeValoresHistoricoReajuste($params);
                
                $valor = $this->contratoService->atualizarValoresNegociacaoContrato($codNego, $nrorg, $cdoperador);
                $this->contratoService->atualizarValoresDescontoPorPeriodoDaNegociacao($valor, $codNego, $nrorg, $cdoperador);
                $this->reajustarParcelasNegociacao($nrSeqcontrato, $codNego, $nrorg, $cdoperador, $nrultimoReajuste);
            }

            $this->contratoService->executarProcedureFctGerarParcelasFatura($nrSeqcontrato, $nrorg, $cdoperador);
            
            $this->refazerIntegracaoOM($nrSeqcontrato, $nrorg);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    public function reajustarItensContrato($row, $nrorg, $cdoperador)
    {
        $this->connection->beginTransaction();
        try {
            /* -- Dados do Contrato -- */
            $nrSeqcontrato = $row['NRSEQCONTRATO'];
            //$nrItemContrato = $row['NRITEMOCONTRATO'];
            $idreajuste = $row['IDREAJUSTE'];
            
            /* -- Percentual -- */
            $percentual = $row['PERCENTUAL'];
            
            /* -- Indice Financeiro -- */
            $cdTpIndice = $row['CDTPINDICE'];
            $idPerValor = $row['IDPERVALOR'];
            $cdIndice  = $row['CDINDICE'];
            $percIndice = $row['PERCINDICE'];

            /* -- Justificativa -- */
            $dsjustificativaitens = $row['DSJUSTIFICATIVA'];
            
            /* -- Valor Fixo -- */
            $valorFixo = $row['VALORFIXO'];
            $vrPercVarIt = $row['VRPERCVARIACAOIT'];

            $codNegociacoes = array();
            
            $nrultimoReajuste = $this->newCode->getCodeByTableName("FCT_NRULTIMOREAJUSTE", $nrorg, 1, 10, true);

            $itensParaAtualizar = $row["ITENS"];
            $utilizaComposicao = $row["UTILIZACOMPOSICAO"];

            if ($utilizaComposicao == "S") {
                for ($i = 0; $i < count($itensParaAtualizar); $i++) {
                    if (!$itensParaAtualizar[$i]["NRITEMCONTRATOPAI"]) {
                        unset($itensParaAtualizar[$i]);
                    }
                }

                $this->atualizarValorItensContratoComReajuste($nrSeqcontrato, $itensParaAtualizar, $idreajuste, $percentual, $dsjustificativaitens, $percIndice, $valorFixo, $cdTpIndice, $idPerValor, $cdIndice, $vrPercVarIt, $nrorg, $cdoperador, $nrultimoReajuste);
                $this->atualizarValorItensPaiContrato($nrSeqcontrato, $nrorg, $cdoperador, $nrultimoReajuste);
            }
            else {
                if (empty($itensParaAtualizar) || (is_array($itensParaAtualizar) && count($itensParaAtualizar) == 0)) {
                    $itensParaAtualizar = $this->getItensPaiNegociacaoContrato($nrSeqcontrato, $nrorg);
                }
                $this->atualizarValorItensContratoComReajuste($nrSeqcontrato, $itensParaAtualizar, $idreajuste, $percentual, $dsjustificativaitens, $percIndice, $valorFixo, $cdTpIndice, $idPerValor, $cdIndice, $vrPercVarIt, $nrorg, $cdoperador, $nrultimoReajuste);
            }

            foreach ($itensParaAtualizar as $item) {
                if (!in_array($item["NRNEGOCIACAOCONTRATO"], $codNegociacoes)) {
                    $codNegociacoes[] = $item["NRNEGOCIACAOCONTRATO"];
                }
            }
            
            foreach ($codNegociacoes as $codNego) {
                //Inserir na tabela FCT_NEGOCIACAOCONTRATO_HR
                $params = $this->getParametroNegociacaoContratoHistoricoRejuste($codNego, $nrorg, $cdoperador, $nrultimoReajuste);
                $this->reajusteContratoFactory->inserirNegociacaoDeValoresHistoricoReajuste($params);
                
                $valor = $this->contratoService->atualizarValoresNegociacaoContrato($codNego, $nrorg, $cdoperador);
                $this->contratoService->atualizarValoresDescontoPorPeriodoDaNegociacao($valor, $codNego, $nrorg, $cdoperador);
                $this->reajustarParcelasNegociacao($nrSeqcontrato, $codNego, $nrorg, $cdoperador, $nrultimoReajuste);
            }

            $this->contratoService->executarProcedureFctGerarParcelasFatura($nrSeqcontrato, $nrorg, $cdoperador);
            $this->refazerIntegracaoOM($nrSeqcontrato, $nrorg);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    private function atualizarValorItensPaiContrato($nrSeqcontrato, $nrorg, $cdoperador, $nrultimoReajuste)
    {
        $itensPai = $this->getItensPaiNegociacaoContrato($nrSeqcontrato, $nrorg);
        foreach ($itensPai as $item) {
            $params = array(
                "NRSEQCONTRATO"     => $nrSeqcontrato,
                "NRORG"             => $nrorg,
                "NRITEMCONTRATOPAI" => $item["NRITEMOCONTRATO"],
            );
            $dataset = $this->contratoFactory->getSomaValorItensFilhosContrato($params);
            $somaValoresItem = (float)$dataset[0]["VRTOTAL"];
            
            // gera a tabela de historico FCT_ITEMCONTRTO_HR
            $params = $this->getParametroItemContratoHistoricoReajuste($item, $nrorg, $cdoperador, $nrultimoReajuste);
            $this->reajusteContratoFactory->inserirHistoricoItemContrato($params);
            
            $params = array(
                "VRUNITITEMCONT"  => $somaValoresItem,
                "NRORGULTATU"     => $nrorg,
                "CDOPERULTATU"    => $cdoperador,
                "NRITEMOCONTRATO" => $item["NRITEMOCONTRATO"],
                "NRORG"           => $nrorg
            );
            $this->reajusteContratoFactory->atualizarValorItemContrato($params);
            
            $params = array(
                "NRNEGOCIACAOCONTRATO" => $item["NRNEGOCIACAOCONTRATO"],
                "NRITEMOCONTRATO"      => $item["NRITEMOCONTRATO"],
                "NRORG"                => $nrorg
            );
            $dataset = $this->contratoFactory->getSomaValorElementosItemNegociacao($params);
            $somaValoresItem = (float)$dataset[0]["VRTOTAL"];
            
            //inserir na tabela FCT_ITNEGOCONTRAT_HR
            $somaValoresItem = (float)$dataset[0]["VRTOTAL"];
            $params = $this->getParametroItensNegociacaoContrato($item, $nrorg, $cdoperador, $nrultimoReajuste);
            $this->reajusteContratoFactory->inserirHistoricoItensNegociacao($params);
            
            $params = array(
                "VRTOTITEM"            => $somaValoresItem,
                "CDOPERULTATU"         => $cdoperador,
                "NRORGULTATU"          => $nrorg,
                "NRNEGOCIACAOCONTRATO" => $item["NRNEGOCIACAOCONTRATO"],
                "NRITEMOCONTRATO"      => $item["NRITEMOCONTRATO"],
                "NRORG"                => $nrorg
            );
            $this->contratoFactory->atualizarValorItemNegociacao($params);
        }
    }
    
    /**
     * A função "calculaReajusteItem" realiza o cálculo dos itens para o reajuste do contrato.
     */
    public function calculaReajusteItem($vrunitario, $quantidade, $medida, $qtmedida, $desconto, $vrdesconto, $percentual, $percIndice, $valorFixo)
    {
        
        /* 1 - Reajusta o valor unitário */

        if ($percentual != null) {
            /* Se o reajuste for percentual*/
            $vrunitAux =  $vrunitario * $percentual / 100;
            $vrunitReaj =  $vrunitario + $vrunitAux;
        } elseif ($percIndice != null) {
            /* Se o reajuste for pelo indice financeiro */
            $vrunitAux =  $vrunitario * $percIndice/ 100;
            $vrunitReaj =  $vrunitario + $vrunitAux;
        } elseif ($valorFixo != null) {
            $vrunitReaj = $valorFixo;
        }
        
        $vrtotaux = $vrunitReaj * $quantidade;
           
        /* Se considerar o cálculo da medida */
        if ($medida == 'S') {
            $vrtotaux = $vrtotaux * $qtmedida;
        }
       
        /* Se considerar desconto percentual */
        if ($desconto == 'P') {
            $vrtotdesc =   $vrtotaux * 100 / $vrdesconto;
            $vrtotaux = $vrtotaux - $vrtotdesc;
        }
        /* Se considerar desconto por valor */
        elseif ($desconto == 'V') {
            $vrtotaux = $vrtotaux - $vrdesconto;
        }
       
        $vrTotalNovo = $vrtotaux;
       
        $iemsReaj = array(
            "VRUNITARIO" => $vrunitReaj,
            "VRTOTAL" => $vrTotalNovo
        );
      
        return $iemsReaj;
    }
    
    /**
     * A função "recebeItensContrato" recebe os itens do Contrato
     */
     
    public function recebeItensContrato($nrSeqcontrato, $nrItemContrato, $nrorg)
    {
        $params = array(
            "NRSEQCONTRATO" => $nrSeqcontrato,
            "NRITEMOCONTRATO" => $nrItemContrato,
            "NRORG"  => $nrorg
        );
        
        return $this->reajusteContratoFactory->recebeItensContrato($params);
    }
  
    /**
     * A função "gravarReajuste" insere o registro do reajuste.
     */
    public function gravarReajuste($nrSeqcontrato, $nrItemContrato, $idreajuste, $percentual, $cdTpIndice, $idPerValor, $cdIndice, $percIndice, $dsjustificativa, $valorFixo, $vrPercVarIt, $vrTotalAnt, $vrTotalNovo, $nrorg, $cdoperador, $nrultimoReajuste, $nrseqprorrcontrato = null)
    {
        $nrContReajuste = $this->newCode->getCodeByTableName("FCT_CONTRATOREAJUSTE", $nrorg, 1, 10, true);
        $params = array(
            "NRCONTREAJUSTE"   => $nrContReajuste,
            "NRSEQCONTRATO"    => $nrSeqcontrato,
            "NRITEMOCONTRATO"  => $nrItemContrato,
            "IDREAJUSTE"       => $idreajuste,
            "PERCENTUAL"       => $percentual,
            "CDTPINDICE"       => $cdTpIndice,
            "IDPERVALOR"       => $idPerValor,
            "CDINDICE"         => $cdIndice,
            "PERCINDICE"       => $percIndice,
            'DSJUSTIFICATIVA'  => $dsjustificativa,
            "VRTOTITEMCONT"    => $vrTotalAnt,
            "VRTOTAL"          => $vrTotalNovo,
            "VRPERCVARIACAOIT" => $vrPercVarIt,
            "NRORG"            => $nrorg,
            "CDOPERADOR"       => $cdoperador,
            "NRSEQPRORRCONT"   => $nrseqprorrcontrato,
            "NRULTIMOREAJUSTE" => $nrultimoReajuste
        );
        
        $this->reajusteContratoFactory->gravarReajuste($params);
    }
    
    
    
    /**
     * Função privada usada para pegar as datas anteriores a relacionada a tabela FCT_CONTRATO de número igual ao parametro
    */
    private function pegarDataAnteriorDoContrato($nrseqcontrato)
    {
        $params = array(
           "NRSEQCONTRATO" => $nrseqcontrato
        );
        return $this->reajusteContratoFactory->pegarDataAnteriorDoContrato($params);
    }
    
    /**
     * A função "alteraItemContrato" altera os dados do item do contrato.
     */
    public function alteraItemContrato($nrSeqcontrato, $nrItemContrato, $vrunitReaj, $vrTotalNovo, $nrorg, $cdoperador)
    {
        $params = array(
            
            "NRSEQCONTRATO" => $nrSeqcontrato,
            "NRITEMOCONTRATO" => $nrItemContrato,
            "VRUNITARIO" =>$vrunitReaj,
            "VRTOTAL" => $vrTotalNovo,
            "NRORG"  => $nrorg,
            "CDOPERADOR" => $cdoperador
        );
        
        $this->reajusteContratoFactory->alteraItemContrato($params);
    }
    
    /**
    * A função "executarProcedureFctVencPrevCont" executa a procedure
    * "FCT_VENCPREV_CONT".
    */
     
    public function executarProcedureFctVencPrevCont($nrseqcontrato, $nrorg)
    {
        $procedure = new FctVencPrevCont($this->connection);
        $procedure->executar($nrseqcontrato, $nrorg);
    }

    public function getItensFilhosContrato($nrSeqcontrato, $nrorg)
    {
        $params = array(
            "NRSEQCONTRATO" => $nrSeqcontrato,
            "NRORG"         => $nrorg
        );
        
        return $this->reajusteContratoFactory->getItensFilhosContrato($params);
    }
    
    public function getItensPaiNegociacaoContrato($nrSeqcontrato, $nrorg)
    {
        $params = array(
            "NRSEQCONTRATO" => $nrSeqcontrato,
            "NRORG"         => $nrorg
        );
        
        return $this->reajusteContratoFactory->getItensPaiNegociacaoContrato($params);
    }

    public function calcularReajuste($valor, $idreajuste, $percentual, $percIndice, $valorFixo)
    {
        if ($idreajuste == "P") { // percentual
            return round($valor + ($valor * $percentual / 100), 2);
        } elseif ($idreajuste == "I") { // indice financeiro
            return round($valor + ($valor * $percIndice / 100), 2);
        } else { // "V" = valor fixo
            return $valorFixo;
        }
    }

    public function atualizarValorItensContratoComReajuste($nrSeqcontrato, $itensParaAtualizar, $idreajuste, $percentual, $dsjustificativa, $percIndice ,$valorFixo, $cdTpIndice, $idPerValor, $cdIndice, $vrPercVarIt, $nrorg, $cdoperador, $nrultimoReajuste, $nrseqprorrcontrato = null)
    {

        foreach ($itensParaAtualizar as $item) {
            // gera a tabela de historico FCT_ITEMCONTRTO_HR
            $params = $this->getParametroItemContratoHistoricoReajuste($item, $nrorg, $cdoperador, $nrultimoReajuste);
            $this->reajusteContratoFactory->inserirHistoricoItemContrato($params);
            
            $novoValorUnitario = $this->calcularReajuste($item["VRUNITITEMCONT"], $idreajuste, $percentual, $percIndice, $valorFixo);
            $qtdMedida         = $item["QTMEDIDACONTR"];
            
            if ($qtdMedida == null || $qtdMedida == 0) {
                $qtdMedida = 1;
            }
            $novoValorTotal = $novoValorUnitario * $item["QTITEMCONTRATO"] * $qtdMedida;
            
            $params = array(
                "VRUNITITEMCONT"  => $novoValorUnitario,
                "NRORGULTATU"     => $nrorg,
                "CDOPERULTATU"    => $cdoperador,
                "NRITEMOCONTRATO" => $item["NRITEMOCONTRATO"],
                "NRORG"           => $nrorg
            );
            
            $this->reajusteContratoFactory->atualizarValorItemContrato($params);
            $params = $this->getParametroItensNegociacaoContrato($item, $nrorg, $cdoperador, $nrultimoReajuste);
            $this->reajusteContratoFactory->inserirHistoricoItensNegociacao($params);
            
            $this->gravarReajuste($nrSeqcontrato, $item["NRITEMOCONTRATO"], $idreajuste, $percentual, $cdTpIndice, $idPerValor, $cdIndice, $percIndice, $dsjustificativa, $valorFixo, $vrPercVarIt, $item["VRTOTITEMCONT"], $novoValorTotal, $nrorg, $cdoperador, $nrultimoReajuste, $nrseqprorrcontrato);
            if ($item["NRNEGOCIACAOCONTRATO"]) {
                $params = array(
                    "VRTOTITEM"            => $novoValorTotal,
                    "CDOPERULTATU"         => $cdoperador,
                    "NRORGULTATU"          => $nrorg,
                    "NRNEGOCIACAOCONTRATO" => $item["NRNEGOCIACAOCONTRATO"],
                    "NRITEMOCONTRATO"      => $item["NRITEMOCONTRATO"],
                    "NRORG"                => $nrorg
                );
                $this->contratoFactory->atualizarValorItemNegociacao($params);
            }
        }
    }

    public function reajustarParcelasNegociacao($nrseqcontrato, $nrnegociacaocontrato, $nrorg, $cdoperador, $nrultimoReajuste)
    {
        $params = array(
            "NRSEQCONTRATO"        => $nrseqcontrato,
            "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
            "NRORG"                => $nrorg
        );
        $dataset = $this->reajusteContratoFactory->getValorNegociacaoComSomaParcelas($params);
        
                
        if (count($dataset) > 0) {
            $valorNegociacao = $dataset[0]["VRTOTITEMCOMDESC"];
            $somaParcelas = $dataset[0]["SOMA_PARCELAS"];
            if (!is_null($somaParcelas) && $valorNegociacao != $somaParcelas) {
                $diferenca = $valorNegociacao - $somaParcelas;
                $percentual = $diferenca / $somaParcelas * 100;
                
                //Inserir na tabela FCT_PARCELANEGOCONT_HR
                $parcela = $this->getParcelasDaNegociacao($nrnegociacaocontrato, $cdoperador);
                for ($i = 0;$i < count($parcela); $i++) {
                    //Criar os parametros para inserção
                    $params = $this->getParametroParcelaNegoContratoHistoricoReajuste($parcela[$i], $nrorg, $nrultimoReajuste);
                    //efetuar a insercao
                    $this->reajusteContratoFactory->inserirHistoricoParcelaNegoContrato($params);
                }
                
                $params = array(
                    "VRPERCENTUAL"         => $percentual,
                    "NRORGULTATU"          => $nrorg,
                    "CDOPERULTATU"         => $cdoperador,
                    "NRNEGOCIACAOCONTRATO" => $nrnegociacaocontrato,
                    "NRORG"                => $nrorg
                );
                $this->reajusteContratoFactory->reajustarParcelasNegociacao($params);
            }
        }
    }
    
    /**
     * Busca as informações do contrato e caso ele seja de composição de
     * serviço, refaz a integração com o OM
    **/
    public function refazerIntegracaoOM($nrseqcontrato, $nrorg)
    {
        $params   = array(
            "NRSEQCONTRATO" => $nrseqcontrato,
            "NRORG"         => $nrorg
        );
        $utilizacomp = $this->reajusteContratoFactory->getElementosContrato($params);
        if ($utilizacomp[0]['QTELEMENTOS'] > 0) {
            $this->integracaoOmService->integracaoOM(null, $nrorg, 'S', true, $nrseqcontrato);
        }
    }
    
    
    /**
     * Busca o parâmetro de bloqueio de reajuste de contrato e valida se
     * deve ser realizado o bloqueio.
    **/
    
    public function validaBloqReajusteContrato($nrorg, $contratos = null)
    {
        /* 1 - recebe o valor do parâmetro "Bloquear reajuste de contrato caso não haja alíquota do índice financeiro cadastrada?"
               da tela "Parametrização SM" */

        $params = array(
            "NRORG"  => $nrorg
        );
        
        $idbloqreajsemaliqAux = $this->reajusteContratoFactory->getIdBloqReajSemAliq($params);
        $idbloqreajsemaliq    = $idbloqreajsemaliqAux[0]['IDBLOQREAJSEMALIQ'];
        
        /*2 - Valida os bloqueios de acordo com o parametrizado.*/
        
        /**
        *  Se parâmetro estiver marcado como "TODOS", deve ser feita a verificação de todos os indices que estão
        * sendo utilizados e, caso algum esteja sem aliquota cadastrada, a função deve retornar "BLOQUEAR",
        * onde no Front a rotina irá bloquar todas as ações da tela.  Caso contrário a função deve retornar "NÃO"
        * e a rotina continua funcionando corretamente.
        **/
        
        if ($idbloqreajsemaliq == 'TODOS') {
            $params   = array(
                "NRORG"  => $nrorg
            );
            
            $indices = $this->reajusteContratoFactory->getIndices($params);
            $erro    = 0;
            
            foreach ($indices as $indice) {
                $params   = array(
                    "CDTPINDICE" => $indice["CDTPINDICE"],
                    "IDPERVALOR" => $indice["IDPERVALOR"],
                    "CDINDICE"   => $indice["CDINDICE"],
                    "NRORG"      => $nrorg
                );
                
                $qtindicesAux = $this->reajusteContratoFactory->getValidaIndicesCad($params);
                $qtindices = $qtindicesAux[0]["QTINDICES"];
                if ($qtindices < 12) {
                    $erro = $erro + 1;
                }
            }
            
            $retorno = ($erro == 0) ? "NAO" : "BLOQUEAR";
        }
        
        /*Se parametro estiver marcado como "INDIVIDUAL" a rotina continua normalmente e a validação é realizada
        para cada contrato individualemnte no ato do reajuste.*/
        elseif ($idbloqreajsemaliq == "INDIVIDUAL") {
            foreach ($contratos as $contrato) {
                $retorno = $this->validaBloqReajusteContrIndividual($nrorg, $contrato["NRSEQCONTRATO"], $contrato["NRTIPOORCAMENTO"]);
                if ($retorno != "NAO") {
                    if ($retorno == "BLOQUEAR") {
                        $retorno = "INDIVIDUAL";
                    }
                    break;
                }
            }
        }
        
        /*Se parametro estiver marcado como "NÃO", significa que não deve ser realizada nenhuma validação e a
        rotina continua funcionando corretamente.*/
        else {
            $retorno = $idbloqreajsemaliq;
        }

        return $retorno;
    }
    
    
    /**
     * Busca o parâmetro de bloqueio de reajuste de contrato e valida se
     * deve ser realizado o bloqueio INDIVIDUALMENTE para cada contrato.
    **/
    
    public function validaBloqReajusteContrIndividual($nrorg, $nrseqcontrato, $nrtipoorcamento)
    {
        
        /* 1 - recebe o valor do parâmetro "Bloquear reajuste de contrato caso não haja alíquota do índice financeiro cadastrada?"
               da tela "Parametrização SM" */
               
        $params = array(
            "NRORG" => $nrorg
        );
        
        $idbloqreajsemaliqAux = $this->reajusteContratoFactory->getIdBloqReajSemAliq($params);
        $idbloqreajsemaliq = $idbloqreajsemaliqAux[0]['IDBLOQREAJSEMALIQ'];
        
        $telaBloqueio = ''; /*Este parêmtro define em qual tela está sendo considerada a parametrização utilizada para este contrato. Será utilzado posteriormente para realziar outra validação na função*/
        
        /*2 - Valida os bloqueios de acordo com o parametrizado.*/
        
        /* Se parâmetro estiver marcado como "INDIVIDUAL", deve ser feita a verificação de todos os indices que estão
           sendo utilizados para o contrato em específico e, caso algum esteja sem aliquota cadastrada, a função deve retornar "BLOQUEAR",
           onde no Front a rotina irá bloquear o reajuste do contrato.  Caso contrário a função deve retornar "NÃO"
           e a rotina continua funcionando corretamente.
        */
        
        if ($idbloqreajsemaliq == 'INDIVIDUAL') {
            $erro = 0;
           
            $params   = array(
                "NRORG"         => $nrorg,
                "NRSEQCONTRATO" => $nrseqcontrato
            );
            
            $indicesContr = $this->reajusteContratoFactory->getIndicesContr($params);
            
            if (!empty($indicesContr)) {
                $indices = $indicesContr;
                $telaBloqueio = 'CONTRATO';
            } else {
                $params = array(
                    "NRORG"           => $nrorg,
                    "NRTIPOORCAMENTO" => $nrtipoorcamento
                );
                
                $indicesEscopo = $this->reajusteContratoFactory->getIndicesEscopo($params);
                
                if (!empty($indicesEscopo)) {
                    $indices = $indicesEscopo;
                    $telaBloqueio = 'ESCOPO';
                } else {
                    $params   = array(
                        "NRORG"  => $nrorg
                    );
                    
                    $indicesParamSM = $this->reajusteContratoFactory->getIndicesParamSM($params);
                    
                    if (!empty($indicesParamSM)) {
                        $indices = $indicesParamSM;
                        $telaBloqueio = 'PARAM';
                    } else {
                        $indices = null;
                    }
                }
            }
            
            if ($indices != null) {
                foreach ($indices as $indice) {
                    $params   = array(
                        "NRSEQCONTRATO" => $nrseqcontrato,
                        "CDTPINDICE" => $indice["CDTPINDICE"],
                        "IDPERVALOR" => $indice["IDPERVALOR"],
                        "CDINDICE"   => $indice["CDINDICE"],
                        "NRORG"      => $nrorg
                    );
                    
                    $qtindicesAux = $this->reajusteContratoFactory->getValidaIndicesCadContrato($params);
                    $qtindices = $qtindicesAux[0]["QTINDICES"];
                    
                    if ($qtindices < 12) {
                        $erro = $erro + 1;
                    }
                }
            } else {
                $erro = -1;
            }
            
            if ($erro == 0) {
                $retorno = $this->validaParamIndiceReajuste($nrorg, $nrseqcontrato, $nrtipoorcamento, $telaBloqueio);
            } elseif ($erro == -1) {
                $retorno = 'BLOQ_SEM_PARAM';
            } else {
                $retorno = "BLOQUEAR";
            }
        } else {
            $retorno = $this->validaParamIndiceReajuste($nrorg, $nrseqcontrato, $nrtipoorcamento, $telaBloqueio);
        }

        return $retorno;
    }
    
    /**
    * Esta função verifica se a parametrização dos índices de reajuste está considerando os
    * 100% necessáios para a realziação do reajuste
    **/
    public function validaParamIndiceReajuste($nrorg, $nrseqcontrato, $nrtipoorcamento, $telaBloqueio)
    {
        /* Se parâmetro $telaBloqueio estiver vazio, significa que a parametrização de verificação de reajuste não está "INDIVIDUAL", neste caso, deve ser testado caso a caso para ver de onde está sendo considerada a parametrização dos percentuais dos índices */
        if ($telaBloqueio == '') {
            $params   = array(
                "NRORG"         => $nrorg,
                "NRSEQCONTRATO" => $nrseqcontrato
            );
            
            $valIndicesContr = $this->reajusteContratoFactory->validaPercIndicesContr($params);
            if (!empty($valIndicesContr)) {
                if ($valIndicesContr[0]['PERCENTUAL'] == 100) {
                    $retorno = 'NAO';
                } else {
                    $retorno = 'BLOQ_PERC_CONTR';
                }
            } else {
                $params   = array(
                    "NRORG"           => $nrorg,
                    "NRTIPOORCAMENTO" => $nrtipoorcamento
                );
                
                $valIndicesEscopo = $this->reajusteContratoFactory->validaPercIndicesEscopo($params);
                if (!empty($valIndicesEscopo)) {
                    if ($valIndicesEscopo[0]['PERCENTUAL'] == 100) {
                        $retorno = 'NAO';
                    } else {
                        $retorno = 'BLOQ_PERC_ESCOPO';
                    }
                } else {
                    $params   = array(
                        "NRORG"    => $nrorg
                    );
                    
                    $valIndicesParam = $this->reajusteContratoFactory->validaPercIndicesParamSM($params);
                    if (!empty($valIndicesEscopo)) {
                        if ($valIndicesParam[0]['PERCENTUAL'] == 100) {
                            $retorno = 'NAO';
                        } else {
                            $retorno = 'BLOQ_PERC_PARAM';
                        }
                    } else {
                        $retorno = 'BLOQ_SEM_PARAM';
                    }
                }
            }
        }
        
        /* Se parâmetro $telaBloqueio NÃO estiver vazio, significa que a parametrização de verificação de reajuste está "INDIVIDUAL", neste caso, deve ser testado o caso exato de onde está sendo considerada a parametrização dos percentuais dos índices */
        elseif ($telaBloqueio == 'CONTRATO') {
            $params   = array(
                "NRORG"         => $nrorg,
                "NRSEQCONTRATO" => $nrseqcontrato
            );
            
            $valIndicesContr = $this->reajusteContratoFactory->validaPercIndicesContr($params);
            if ($valIndicesContr[0]['PERCENTUAL'] == 100) {
                $retorno = 'NAO';
            } else {
                $retorno = 'BLOQ_PERC_CONTR';
            }
        } elseif ($telaBloqueio == 'ESCOPO') {
            $params   = array(
                "NRORG"           => $nrorg,
                "NRTIPOORCAMENTO" => $nrtipoorcamento
            );
            
            $valIndicesEscopo = $this->reajusteContratoFactory->validaPercIndicesEscopo($params);
            if ($valIndicesEscopo[0]['PERCENTUAL'] == 100) {
                $retorno = 'NAO';
            } else {
                $retorno = 'BLOQ_PERC_ESCOPO';
            }
        } elseif ($telaBloqueio == 'PARAM') {
            $params   = array(
                "NRORG" => $nrorg
            );
            
            $valIndicesParam = $this->reajusteContratoFactory->validaPercIndicesParamSM($params);
            if ($valIndicesParam[0]['PERCENTUAL'] == 100) {
                $retorno = 'NAO';
            } else {
                $retorno = 'BLOQ_PERC_PARAM';
            }
        }
        
        return $retorno;
    }
    
    /**
     *  Reajusta os contratos em Massa
    **/
    public function reajusteContrMassa($contratos, $operador, $renovacaoContrato = false, $nrseqprorrcontrato = null, $processoAutomatico = false, $dataReajuste = null, $diasReajuste = null)
    {
        /*O parametro $renovacaoContrato vem como true caso a função seja chamada da tela de renovação de contrato.
        Nessa tela, logo após reajustar o contrato vai ser alterado o seu período de vigência, então aqui
        não tem a necessidade de chamar a integração com o OM e regerar o faturamento, pois isso já será
        feito no final do processo de renovação.*/
        
        $indicesContrato = array();
        $contratosDif    = array();
        
        foreach ($contratos as $contrato) {
            if (array_key_exists((string) $contrato["NRSEQCONTRATO"], $indicesContrato)) {
                $indicesContrato[$contrato["NRSEQCONTRATO"]] += round(($contrato['VRINDICE'] * $contrato['NRPERCENTINDICE']) / 100, 4);
            } else {
                $indicesContrato[$contrato["NRSEQCONTRATO"]] = round(($contrato['VRINDICE'] * $contrato['NRPERCENTINDICE']) / 100, 4);
                array_push($contratosDif, $contrato);
            }
        }
        
        /*if (!$processoAutomatico) {
            $nrultimoReajuste = $this->newCode->getCodeByTableName("FCT_NRULTIMOREAJUSTE", $contratos["NRORG"], 1, 10, true);
        } else {
            $nrultimoReajuste = $this->newCode->getCodeByTableName("FCT_NRULTIMOREAJUSTE", $contratos[0]["NRORG"], 1, 10, true);
        }*/
        $nrultimoReajuste = $this->newCode->getCodeByTableName("FCT_NRULTIMOREAJUSTE", $contratos[0]["NRORG"], 1, 10, true);
        
        foreach ($contratosDif as $contrato) {
            $dsjustificativa = isset($contrato['DSJUSTIFICATIVA']) ? $contrato['DSJUSTIFICATIVA'] : null;
            if($processoAutomatico) {
                $dataAnterior = $contrato["DTPADREAJCONT"]; // valor usado como cache da data padrão usada na geração do log do relatório
                $dsjustificativa = 'Inserido pela rotina automática de Reajuste de Contratos';
            }
            $params = array(
                "NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"]
            );
            $valorAntesReajuste = $this->reajusteContratoFactory->getValorContrato($params);
            $valorAntesReajuste = $valorAntesReajuste[0]["VRCONTRATO"];
            $this->connection->beginTransaction();
            try {
                $nrseqcontrato      = $contrato["NRSEQCONTRATO"];
                $nrorg              = $contrato["NRORG"];

                $usaComposicao = true;
                $itensParaAtualizar = $this->getItensFilhosContrato($nrseqcontrato, $nrorg);
                if (count($itensParaAtualizar) == 0) {
                    $usaComposicao = false;
                    $itensParaAtualizar = $this->getItensPaiNegociacaoContrato($nrseqcontrato, $nrorg);
                }
                    
                $idreajuste = 'I';
                $percentual = 0;
                $percIndice = $indicesContrato[$nrseqcontrato];
                
                $percentualUtilizado = $percIndice;
                
                if (empty($contrato["CDTPINDICE"])) {
                    $idreajuste = 'P';
                    $percentual = $contrato["VRINDICE"];
                    $percIndice = 0;
                    $percentualUtilizado = $percentual;
                }
                
                $this->atualizarValorItensContratoComReajuste($nrseqcontrato, $itensParaAtualizar, $idreajuste, $percentual, $dsjustificativa, $percIndice, 0, $contrato["CDTPINDICE"], $contrato["IDPERVALOR"], $contrato["CDINDICE"], 0, $nrorg, $operador, $nrultimoReajuste, $nrseqprorrcontrato);
                if ($usaComposicao) {
                    $this->atualizarValorItensPaiContrato($nrseqcontrato, $nrorg, $operador, $nrultimoReajuste);
                }
                
                $codNegociacoes = array();
                foreach ($itensParaAtualizar as $item) {
                    if (!in_array($item["NRNEGOCIACAOCONTRATO"], $codNegociacoes)) {
                        $codNegociacoes[] = $item["NRNEGOCIACAOCONTRATO"];
                    }
                }

                foreach ($codNegociacoes as $codNegociacao) {
                    //Inserir na tabela FCT_NEGOCIACAOCONTRATO_HR
                    $params = $this->getParametroNegociacaoContratoHistoricoRejuste($codNegociacao, $nrorg, $operador, $nrultimoReajuste);
                    $this->reajusteContratoFactory->inserirNegociacaoDeValoresHistoricoReajuste($params);
                    
                    $valor = $this->contratoService->atualizarValoresNegociacaoContrato($codNegociacao, $nrorg, $operador);
                    $this->contratoService->atualizarValoresDescontoPorPeriodoDaNegociacao($valor, $codNegociacao, $nrorg, $operador);
                    $this->reajustarParcelasNegociacao($nrseqcontrato, $codNegociacao, $nrorg, $operador, $nrultimoReajuste);
                }
                
                if (!$renovacaoContrato) { //$renovacaoContrato = ler comentário no início dessa função
                    $this->contratoService->executarProcedureFctGerarParcelasFatura($nrseqcontrato, $nrorg, $operador);
                    
                    //$this->refazerIntegracaoOM($nrseqcontrato, $nrorg);
                    $this->contratoService->atualizarValorLinhaProduto($nrseqcontrato, $operador, $nrorg);
                }
                //atualizando a data padrão do reajuste automatico
                if ($processoAutomatico) {
                    $this->atualizarDataPadraoDeReajuste($contrato["NRSEQCONTRATO"]);
                }else if($renovacaoContrato && $dataReajuste){
                    $this->atualizarDataPadraoDeReajuste($contrato["NRSEQCONTRATO"], $dataReajuste, $diasReajuste);
                }
                
                if ($processoAutomatico) {
                    //recalcular a medição
                    $params = array(
                        "NRSEQCONTRATO" => $contrato["NRSEQCONTRATO"],
                        "DTINICOMPET" => $contrato["DTINIVIGENCONT"],
                        "DTFINCOMPET" => $contrato["DTFINVIGENCONT"]
                    );
                    $nrMedicaoFatura = $this->reajusteContratoFactory->getNumeroMedicaoContrato($params);
                    if (count($nrMedicaoFatura) > 0) {
                        foreach ($nrMedicaoFatura as $numero) {
                            $this->medicaoService->recalcularItensMedicao($numero["NRMEDICAOFATURA"], $contrato["NRSEQCONTRATO"], $nrorg);
                        }
                    }
                    //Mensagem de Log SUCESSO
                    $mensagemLog = "Dados de reajuste atualizados.";
                    $codContrato = isset($contrato["NRCONTRATOFCT"]) ? ($contrato["NRCONTRATOFCT"] . " (" . $contrato["NRSEQCONTRATO"] . ")") : $contrato["NRSEQCONTRATO"];
                    echo "ORGANIZAÇÃO: " . $nrorg . " | Contrato " . $codContrato . " | SUCESSO: " . $mensagemLog . "\n";
                    try {
                        //inserir no log (status: SUCESSO)
                        $params = $this->getParametroLogReajusteAutomatico($contrato, $percentualUtilizado, $valorAntesReajuste, $dataAnterior);
                        $this->reajusteContratoFactory->inserirLogReajusteContrato($params);
                    } catch (\Exception $e) {
                        echo "ORGANIZAÇÃO: " . $nrorg . " - Falha ao inserir log de sucesso do reajuste do contrato " . $contrato["NRSEQCONTRATO"] . ": \n" . $e->getMessage();
                        throw $e;
                    }
                }
                $this->connection->commit();
            } catch (\Exception $e) {
                $this->connection->rollBack();
                if (!$processoAutomatico) {
                    throw $e;
                } else {
                    $mensagemerror = substr($e->getMessage() ,0 ,4000);
                    echo "ORGANIZAÇÃO: " . $nrorg . " | CONTRATO " . $contrato["NRSEQCONTRATO"] . " | ERRO: " . $mensagemerror . "\n";
                    try {
                        //inserir no log (status: ERRO)
                        $params = $this->getParametroLogReajusteAutomatico($contrato, $percentualUtilizado, $valorAntesReajuste, $dataAnterior, $mensagemerror);
                        $this->reajusteContratoFactory->inserirLogReajusteContrato($params);
                    } catch (\Exception $e) {
                        echo "ORGANIZAÇÃO: " . $nrorg . " - Falha ao inserir log de erro do reajuste do contrato " . $contrato["NRSEQCONTRATO"] . ": \n" . $e->getMessage();
                    }
                    return false;
                }
                throw $e;
            }
        }
        return true;
    }
    
    /**
     * Retorna os parametros da tabela CT_PARCELANEGOCONT, que serao usados para inserir na tabela FCT_PARCELANEGOCONT_HR
    */
    private function getParcelasDaNegociacao($nrparcela, $cdoperador)
    {
        $params = array(
            "NRNEGOCIACAOCONTRATO" => $nrparcela
        );
        return $this->reajusteContratoFactory->getParcelasDaNegociacao($params);
    }
    
    /**
     * Retorna os parametros necessários para inserir na tabela FCT_PARCELANEGOCONT_HR
    */
    private function getParametroParcelaNegoContratoHistoricoReajuste($parcela, $nrorg, $nrultimoReajuste)
    {
        $nrParcelaNegoContHR = $this->newCode->getCodeByTableName("FCT_PARCELANEGOCONT_HR", $nrorg, 1, 10, true);
        return array(
            "NRPARCELANEGOCONT_HR" =>   $nrParcelaNegoContHR,
            "NRPARCELANEGOCONT"    =>   $parcela["NRPARCELANEGOCONT"],
            "NRNEGOCIACAOCONTRATO" =>   $parcela["NRNEGOCIACAOCONTRATO"],
            "VRPARCELA"            =>   $parcela["VRPARCELA"],
            "IDATIVO"              =>   $parcela["IDATIVO"],
            "NRORG"                =>   $parcela["NRORG"],
            "CDOPERINCLUSAO"       =>   $parcela["CDOPERINCLUSAO"],
            "NRPARCELA"            =>   $parcela["NRPARCELA"],
            "NRULTIMOREAJUSTE"     =>   $nrultimoReajuste
        );
    }
    
    /**
     * Retorna os parametros necessarios para inserir na tabela FCT_ITNEGOCIACAOCONTRATO_HR
    */
    
    private function getParametroItensNegociacaoContrato($item, $nrorg, $cdoperador, $nrultimoReajuste)
    {
        $nrItemNegociacaoContrato_hr = $this->newCode->getCodeByTableName("FCT_ITNEGOCIACAOCONTRATO_HR", $nrorg, 1, 10, true);
        return array(
            "NRITNEGOCIACAOCONTRATO_HR" => $nrItemNegociacaoContrato_hr,
            "NRITNEGOCIACAOCONTRATO"    => $item["NRITNEGOCIACAOCONTRATO"],
            "CDOPERINCLUSAO"            => $cdoperador,
            "NRULTIMOREAJUSTE"          => $nrultimoReajuste
        );
    }
    
    /**
     * Retorna os parametros necessarios para inserir na tabela FCT_ITEMCONTRATO_HR
    */
    private function getParametroItemContratoHistoricoReajuste($item, $nrorg, $cdoperador, $nrultimoReajuste)
    {
        $nrItemContrato_hr = $this->newCode->getCodeByTableName("FCT_ITEMCONTRATO_HR", $nrorg, 1, 10, true);
        return array(
            "NRITEMCONTRATO_HR" 	 => $nrItemContrato_hr,
            "NRITEMOCONTRATO"   	 => $item["NRITEMOCONTRATO"],
            "CDOPERINCLUSAO"         => $cdoperador,
            "NRULTIMOREAJUSTE"       => $nrultimoReajuste
        );
    }
    
    /**
     * Retorna os parametros necessarios para inserir na tabela FCT_NEGOCIACAOCONTRATO_HR
    */
    private function getParametroNegociacaoContratoHistoricoRejuste($codNego, $nrorg, $cdoperador, $nrultimoReajuste)
    {
        $nrNegociacaoContrato_hr = $this->newCode->getCodeByTableName("FCT_NEGOCIACAOCONTRATO_HR", $nrorg, 1, 10, true);
        return array(
            "NRNEGOCIACAOCONTRATO_HR" => $nrNegociacaoContrato_hr,
            "NRNEGOCIACAOCONTRATO" 	  => $codNego,
            "CDOPERINCLUSAO"          => $cdoperador,
            "NRULTIMOREAJUSTE"        => $nrultimoReajuste
            
        );
    }
    
    private function getParametroLogReajusteAutomatico($contrato, $vrPercentualReajuste, $valorAntesReajuste,$dataAnterior, $mensagemError = null)
    {
        $dados = $this->getDadosReajusteContratoLog($contrato["NRSEQCONTRATO"]);
        $params = array(
            "NRSEQCONTRATO"  		=> $contrato["NRSEQCONTRATO"],
            "DSERRO"         		=> $mensagemError,
            "VRPERCREAJUSTE" 		=> $vrPercentualReajuste,
            "CDTPINDICE"     	   	=> $contrato["CDTPINDICE"],
            "IDPERVALOR"     	   	=> $contrato["IDPERVALOR"],
            "CDINDICE"       	  	=> $contrato["CDINDICE"],
            "VRCONTRATO"     	   	=> $valorAntesReajuste,
            "NRORG"          	   	=> $contrato["NRORG"],
            "DTPRXREAJ"      	   	=> $dados["DTPADREAJCONT"],
            "DTANTREAJ"             => $dataAnterior,
            "VRNVCONTRATO"   	   	=> $dados["VRCONTRATO"]
        );
        return $params;
    }
    
    public function getDadosReajusteContratoLog($nrseqcontrato){
        $params = array(
           "NRSEQCONTRATO" => $nrseqcontrato
        );
        $dados = $this->reajusteContratoFactory->getDadosReajusteContratoLog($params);
        return (count($dados) > 0) ? $dados[0] : array();
    }
    
    public function atualizarDataPadraoDeReajuste($nrseqcontrato , $dataReajuste = null, $diasReajuste = null){
        try{
            if($dataReajuste == null){
                $dados = $this->getDadosReajusteContratoLog($nrseqcontrato);
                $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "DTPADREAJCONT" => $dados["DTPRXREAJCONT"]
                );
                $this->reajusteContratoFactory->atualizarDataPadraoDeReajuste($params);
            }else{
                $params = array(
                    "NRSEQCONTRATO" => $nrseqcontrato,
                    "NRDIASREAJAUTOMATICO" => $diasReajuste,
                    "DTPADREAJCONT" => $dataReajuste
                );
                $this->reajusteContratoFactory->atualizarDataPadraoDeReajusteEDia($params);
            }
        }catch(\Exception $e){
           throw $e; 
        }
    }
    
}
